ThrottledStore

Struct ThrottledStore 

pub struct ThrottledStore<T> { /* private fields */ }
Store wrapper that wraps an inner store with some sleep calls.

This can be used for performance testing.

Note that the behavior of the wrapper is deterministic and might not reflect real-world conditions!

Implementations

Source

impl<T> ThrottledStore<T>

pub fn new(inner: T, config: ThrottleConfig) -> Self

Create new wrapper with zero waiting times.

pub fn config_mut<F>(&self, f: F)
where F: Fn(&mut ThrottleConfig),

Mutate config.

pub fn config(&self) -> ThrottleConfig

Return copy of current config.