pub struct ThrottledStore<T> { /* private fields */ }Expand description
Store wrapper that wraps an inner store with some sleep calls.
This can be used for performance testing.
Note that the behavior of the wrapper is deterministic and might not reflect real-world conditions!
Implementations
Sourceimpl<T> ThrottledStore<T>
impl<T> ThrottledStore<T>
Sourcepub fn new(inner: T, config: ThrottleConfig) -> Self
pub fn new(inner: T, config: ThrottleConfig) -> Self
Create new wrapper with zero waiting times.
Sourcepub fn config_mut<F>(&self, f: F)where
F: Fn(&mut ThrottleConfig),
pub fn config_mut<F>(&self, f: F)where
F: Fn(&mut ThrottleConfig),
Mutate config.
Sourcepub fn config(&self) -> ThrottleConfig
pub fn config(&self) -> ThrottleConfig
Return copy of current config.